@@ -8,12 +8,14 @@ implementing the methods and behaviors for an AMQP Channel.
 import collections
 import logging
 import uuid
+from enum import Enum
 
 import pika.frame as frame
 import pika.exceptions as exceptions
 import pika.spec as spec
 import pika.validators as validators
 from pika.compat import unicode_type, dictkeys, is_integer
+from pika.exchange_type import ExchangeType
 
 LOGGER = logging.getLogger(__name__)
 
@@ -172,10 +174,10 @@ class Channel(object):
         :param callable callback: The function to call, having the signature
                                 callback(channel, method, properties, body)
                                 where
-                                channel: pika.Channel
-                                method: pika.spec.Basic.Return
-                                properties: pika.spec.BasicProperties
-                                body: bytes
+                                 - channel: pika.channel.Channel
+                                 - method: pika.spec.Basic.Return
+                                 - properties: pika.spec.BasicProperties
+                                 - body: bytes
 
         """
         self.callbacks.add(self.channel_number, '_on_return', callback, False)
@@ -282,10 +284,10 @@ class Channel(object):
         :param callable on_message_callback: The function to call when
             consuming with the signature
             on_message_callback(channel, method, properties, body), where
-                channel: pika.Channel
-                method: pika.spec.Basic.Deliver
-                properties: pika.spec.BasicProperties
-                body: bytes
+             - channel: pika.channel.Channel
+             - method: pika.spec.Basic.Deliver
+             - properties: pika.spec.BasicProperties
+             - body: bytes
         :param bool auto_ack: if set to True, automatic acknowledgement mode
             will be used (see http://www.rabbitmq.com/confirms.html).
             This corresponds with the 'no_ack' parameter in the basic.consume
@@ -357,10 +359,10 @@ class Channel(object):
             channel
         :param callable callback: The callback to call with a message that has
             the signature callback(channel, method, properties, body), where:
-            channel: pika.Channel
-            method: pika.spec.Basic.GetOk
-            properties: pika.spec.BasicProperties
-            body: bytes
+             - channel: pika.channel.Channel
+             - method: pika.spec.Basic.GetOk
+             - properties: pika.spec.BasicProperties
+             - body: bytes
         :param bool auto_ack: Tell the broker to not expect a reply
         :raises ValueError:
 
@@ -377,12 +379,12 @@ class Channel(object):
         # frames (or similar)
         self._send_method(spec.Basic.Get(queue=queue, no_ack=auto_ack))
 
-    def basic_nack(self, delivery_tag=None, multiple=False, requeue=True):
+    def basic_nack(self, delivery_tag=0, multiple=False, requeue=True):
         """This method allows a client to reject one or more incoming messages.
         It can be used to interrupt and cancel large incoming messages, or
         return untreatable messages to their original queue.
 
-        :param integer delivery-tag: int/long The server-assigned delivery tag
+        :param integer delivery_tag: int/long The server-assigned delivery tag
         :param bool multiple: If set to True, the delivery tag is treated as
                               "up to and including", so that multiple messages
                               can be acknowledged with a single method. If set
@@ -433,11 +435,12 @@ class Channel(object):
                   global_qos=False,
                   callback=None):
         """Specify quality of service. This method requests a specific quality
-        of service. The QoS can be specified for the current channel or for all
-        channels on the connection. The client can request that messages be sent
-        in advance so that when the client finishes processing a message, the
-        following message is already held locally, rather than needing to be
-        sent down the channel. Prefetching gives a performance improvement.
+        of service. The client can request that messages be sent in advance
+        so that when the client finishes processing a message, the following
+        message is already held locally, rather than needing to be sent down
+        the channel. The QoS can be applied separately to each new consumer on
+        channel or shared across all consumers on the channel. Prefetching
+        gives a performance improvement.
 
         :param int prefetch_size:  This field specifies the prefetch window
                                    size. The server will send a message in
@@ -456,8 +459,8 @@ class Channel(object):
                                    and connection level) allow it. The
                                    prefetch-count is ignored by consumers who
                                    have enabled the no-ack option.
-        :param bool global_qos:    Should the QoS apply to all channels on the
-                                   connection.
+        :param bool global_qos:    Should the QoS be shared across all
+                                   consumers on the channel.
         :param callable callback: The callback to call for Basic.QosOk response
         :raises ValueError:
 
@@ -470,12 +473,12 @@ class Channel(object):
             spec.Basic.Qos(prefetch_size, prefetch_count, global_qos), callback,
             [spec.Basic.QosOk])
 
-    def basic_reject(self, delivery_tag, requeue=True):
+    def basic_reject(self, delivery_tag=0, requeue=True):
         """Reject an incoming message. This method allows a client to reject a
         message. It can be used to interrupt and cancel large incoming messages,
         or return untreatable messages to their original queue.
 
-        :param integer delivery-tag: int/long The server-assigned delivery tag
+        :param integer delivery_tag: int/long The server-assigned delivery tag
         :param bool requeue: If requeue is true, the server will attempt to
                              requeue the message. If requeue is false or the
                              requeue attempt fails the messages are discarded or
@@ -625,7 +628,7 @@ class Channel(object):
 
     def exchange_declare(self,
                          exchange,
-                         exchange_type='direct',
+                         exchange_type=ExchangeType.direct,
                          passive=False,
                          durable=False,
                          auto_delete=False,
@@ -657,6 +660,8 @@ class Channel(object):
         validators.require_string(exchange, 'exchange')
         self._raise_if_not_open()
         nowait = validators.rpc_completion_callback(callback)
+        if isinstance(exchange_type, Enum):
+            exchange_type = exchange_type.value
         return self._rpc(
             spec.Exchange.Declare(0, exchange, exchange_type, passive, durable,
                                   auto_delete, internal, nowait, arguments or
@@ -748,6 +753,15 @@ class Channel(object):
         """
         return self._state == self.OPEN
 
+    @property
+    def is_opening(self):
+        """Returns True if the channel is opening.
+
+        :rtype: bool
+
+        """
+        return self._state == self.OPENING
+
     def open(self):
         """Open the channel"""
         self._set_state(self.OPENING)
@@ -1234,8 +1248,8 @@ class Channel(object):
         if not self.callbacks.process(self.channel_number, '_on_return', self,
                                       self, method_frame.method,
                                       header_frame.properties, body):
-            LOGGER.warning('Basic.Return received from server (%r, %r)',
-                           method_frame.method, header_frame.properties)
+            LOGGER.debug('Basic.Return received from server (%r, %r)',
+                          method_frame.method, header_frame.properties)
 
     def _on_selectok(self, method_frame):
         """Called when the broker sends a Confirm.SelectOk frame
@@ -1290,7 +1304,7 @@ class Channel(object):
                 LOGGER.debug('Ignoring drained blocked method: %s', method)
 
     def _rpc(self, method, callback=None, acceptable_replies=None):
-        """Make a syncronous channel RPC call for a synchronous method frame. If
+        """Make a synchronous channel RPC call for a synchronous method frame. If
         the channel is already in the blocking state, then enqueue the request,
         but don't send it at this time; it will be eventually sent by
         `_on_synchronous_complete` after the prior blocking request receives a
